<?php
/**
 * byzantium functions and definitions
 *
 * @package byzantium
 */

if ( ! function_exists( 'byzantium_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function byzantium_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on byzantium, use a find and replace
	 * to change 'byzantium' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'byzantium', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
        add_image_size('byzantium-large-thumb', 660, 300, true);
	add_image_size('byzantium-small-thumb', 340, 200, true);

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'byzantium' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside'
	) );
}
endif; // byzantium_setup
add_action( 'after_setup_theme', 'byzantium_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function byzantium_content_width() {
	if ( ! isset( $content_width ) ) $content_width = 640;
}
add_action( 'after_setup_theme', 'byzantium_content_width', 0 );



/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function byzantium_widgets_init() {
        
        register_sidebar( array(
                'name' => __( 'Left Sidebar', 'byzantium' ),
                'id' => 'sidebar-1',
                'description' => __( 'The left sidebar of byzantium', 'byzantium' ),
                'before_widget' => '<aside id="%1$s" class="left-widget %2$s">',
                'after_widget'  => '</aside>',
                'before_title'  => '<h2 class="widget-title">',
                'after_title'   => '</h2>',
        ) );
    
	register_sidebar( array(
		'name'          => esc_html__( 'Right Sidebar', 'byzantium' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'The right sidebar of byzantium', 'byzantium' ),
		'before_widget' => '<aside id="%1$s" class="right-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h1>',
	) );
        
        register_sidebar( array(
		'name'          => esc_html__( 'Menu Sidebar', 'byzantium' ),
		'id'            => 'sidebar-3',
		'description'   => __( 'The sidebar holding the menu of byzantium', 'byzantium' ),
		'before_widget' => '<aside id="%1$s" class="menu-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h1>',
	) );
        

}
add_action( 'widgets_init', 'byzantium_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function byzantium_scripts() {
        wp_enqueue_style( 'byzantium-foundation-style', get_stylesheet_directory_uri() . '/foundation/foundation.min.css' );
    
	wp_enqueue_style( 'byzantium-style', get_stylesheet_uri() );
        
        wp_enqueue_style('byzantium-google-fonts', 'http://fonts.googleapis.com/css?family=Lato:400,700,700italic,300,300italic,900,900italic|Merriweather:400,400italic,700,700italic,900,900italic,300italic,300');
        
        wp_enqueue_script( 'byzantium-jquery', get_template_directory_uri() . '/js/jquery-2.1.4.min.js', array(), '20151029', true );
        
        wp_enqueue_script( 'byzantium-superfish', get_template_directory_uri() . '/js/superfish.min.js', array(), '20150704', true );
        
        wp_enqueue_script( 'byzantium-superfish-settings', get_template_directory_uri() . '/js/superfish-settings.js', array('byzantium-superfish'), '20150704', true );

	wp_enqueue_script( 'byzantium-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'byzantium-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'byzantium_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/* Header logo customizer: */

function byzantium_theme_customizer( $wp_customize ) {
    $wp_customize->add_section( 'byzantium_logo_section' , array(
        'title'       => __( 'Logo', 'byzantium' ),
        'priority'    => 40,
        'description' => esc_html__('Upload a logo in the left side of the header','byzantium'),
    ) );
    $wp_customize->add_setting( 'byzantium_logo' , array(
        'sanitize_callback' => 'byzantium_sanitize_logo',
    ) );
    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'byzantium_logo', array(
        'label'    => __( 'Logo', 'byzantium' ),
        'section'  => 'byzantium_logo_section',
        'settings' => 'byzantium_logo',
    ) ) );
    
}
add_action( 'customize_register', 'byzantium_theme_customizer' );

    /**
     * Check Image
     */
    function byzantium_sanitize_logo ( $input ){
     
        /* default output */
        $output = '';
     
        /* check file type */
        $filetype = wp_check_filetype( $input );
        $mime_type = $filetype['type'];
     
        /* only mime type "image" allowed */
        if ( strpos( $mime_type, 'image' ) !== false ){
            $output = $input;
        }
     
        return $output;
    }